@@ -14,7 +14,7 @@
 #'
 #' @family layout_tbl_graph_*
 #'
-#' @importFrom rlang enquo eval_tidy
+#' @importFrom rlang enquo eval_tidy quo_is_symbol
 #'
 layout_tbl_graph_manual <- function(graph, x, y, circular) {
   if (circular) {
@@ -27,6 +27,7 @@ layout_tbl_graph_manual <- function(graph, x, y, circular) {
     y = eval_tidy(y, .N())
   ))
   extra_data <- as_tibble(graph, active = 'nodes')
+  warn_dropped_vars(layout, extra_data)
   layout <- cbind(layout, extra_data[, !names(extra_data) %in% names(layout), drop = FALSE])
   layout$circular <- FALSE
   layout
